/*
************************************************************************
**
** Copyright (c) 2004 The General Electric Company
**
** Author:     Shridhar Nayak
**
** File:      CoilDefs.h
**
** Objective: Stores Coil Config values read for a Rxd Coil from
**            CoilConfig.cfg or CoilDB.
**
**
**    Date        Programmer         Description
**    --------------------------------------------------------
*******************************************************************
*/

#ifndef COIL_DEFS
#define COIL_DEFS


#include "GEtypes.h"
#include "coilIdDefs.h"

/* Maximum length of GE coil name */
#define GE_COIL_NAME_LENGTH 24

/* Actual string length is padded out to a multiple of 64 bits for
 * NULL termination and alignment */
#define GE_COIL_NAME_LENGTH_PADDED 32

/* Maximum coil configurations for a scan */
#define MAX_COIL_SETS 10

/* Maximum transmit coil information for a scan */
#define MAX_TX_COIL_SETS 5

/* Number of parameters in reflCoeffSquared */
#define REFL_COEFF_SQUARED_LENGTH 10
#define NUM_REFLCS_PAIRS REFL_COEFF_SQUARED_LENGTH/2

/* Number of parameters in exposedMass */
#define EXPOSED_MASS_LENGTH 8

/* Number of parameter in jstd */
#define JSTD_LENGTH 12
#define NUM_JSTD_PAIRS JSTD_LENGTH/2

/* Types of receive coils (rxCoilType in COIL_INFO) */
#define RX_COIL_BODY 0
#define RX_COIL_LOCAL 1

/* Types of transmit coils (txCoilType in COIL_INFO) */
#define TX_COIL_BODY 0
#define TX_COIL_LOCAL 1

/* Predefined indicies for COIL_INFO txIndexPri and txIndexSec     */
/*   TX_INDEX_NONE - index indicating no TX coil on the exciter */
/*   TX_INDEX_BODY - index for body primary coil                */
#define TX_INDEX_NONE -1
#define TX_INDEX_BODY 0

/* Values for txAmp (transmit amplifier) field of TX_COIL_INFO */
#define TX_AMP_NB 0
#define TX_AMP_BB 1

/* Transmit positions (txPosition in TX_COIL_INFO) */
#define TX_POS_BODY 0
#define TX_POS_HEAD 1
#define TX_POS_EXTREMITY 2


/*
*   Coil Parameters passed across different subsystems
*/

#define MAX_NUM_CHAN_TRANSLATION_MAPS 4
#define MAX_NUM_RECEIVERS 32

/**
 * The ChannelTranslationTable contains one of these entries per hub index.
 * ChannelTransTableEntryType structure contains coil-related configuration info.
 */
typedef struct CTTEntry
{
    /**
     * The logicalCoilName of Active Coil
     */
    s8 logicalCoilName[128];

    /**
     * The clinicalCoilName of Active Coil 
     */
    s8 clinicalCoilName[32];

    /**
     * A unique identifier based on coil parameters
     */
    n32 configUID;

    /**
     * The coilConnector to which Active Coil is connected 
     */
    s32 coilConnector;

    /**
     * Indicates whether this config is used for active scanning
     */
    n32 isActiveScanConfig;

    /**
     * The channel translation map for this config
     */
    s16 channelTranslationMap[MAX_NUM_RECEIVERS];

} ChannelTransTableEntryType;



/* Spectroscopy definitions */ 
/* Supported Nuclei */
#define PROTON 1
#define DEUTERIUM 2
#define HELIUM 3
#define LITHIUM 7
#define BORON 11
#define CARBON 13
#define NITROGEN 15
#define OXYGEN 17
#define FLUORINE 19
#define SODIUM 23
#define SILICON 29
#define PHOSPHORUS 31
#define XENON 129


#define CFH_SENSITIVE_DEFAULT -1
#define CFH_INSENSITIVE 0
#define CFH_SENSITIVE_NECK_REGION 1
#define CFH_SENSITIVE_BREAST_REGION 2

enum
{
    NORMAL_COIL,
    F000_COIL,
    FG00_COIL,
    P000_COIL,
    PG00_COIL,
    R000_COIL,
    SERV_COIL
};

#define COIL_ID_NOT_FOUND -1

typedef struct _INSTALL_COIL_INFO_
{
    char coilCode[COIL_ID_PADDED_LENGTH];
    int isInCoilDatabase;
}INSTALL_COIL_INFO;

typedef struct _INSTALL_COIL_CONNECTOR_INFO_
{
    int connector;
    int needsInstall;
    INSTALL_COIL_INFO installCoilInfo[NUM_COILS_PER_CONNECTOR];
}INSTALL_COIL_CONNECTOR_INFO;

#endif
