/*
************************************************************************
**
** Copyright (c) 2004 The General Electric Company
**
** Author:     Shridhar Nayak
**
** File:      CoilParameters.h
**
** Objective: Stores Coil Config values read for a Rxd Coil from
**            CoilConfig.cfg or CoilDB.
**
**
**    Date        Programmer         Description
**    --------------------------------------------------------
**    22/03/2004  Shridhar Nayak     New File (Coil ID Feature)
**    07/05/2006  Teja Shubhachint   CIM-PSD Communication
*******************************************************************
*/

#ifndef COIL_PARAMETERS
#define COIL_PARAMETERS

#include "CoilDefs.h"

typedef struct coil_config_params
{
    char coilName[16];
    char GEcoilName[24];
    short pureCorrection;
    int maxNumOfReceivers; /* Maximum Number of Receiver Channels*/
    int coilType;
    int fastTGmode;
    int fastTGstartTA;
    int fastTGstartRG;
    int nuclide;
    int tRPAvolumeRecEnable;
    int pureCompatible;
    int aps1StartTA;
    int cflStartTA;
    int cfhSensitiveAnatomy;
    float cableLoss;
    float coilLoss;
    float reconScale;
    float autoshimFOV;
    float coilWeights[MAX_NUM_CHAN_TRANSLATION_MAPS][MAX_NUM_RECEIVERS];
    ChannelTransTableEntryType cttEntry[MAX_NUM_CHAN_TRANSLATION_MAPS];

} COIL_CONFIG_PARAM_TYPE;

typedef struct application_config_param_type
{
    int aps1StartTA;
    int cflStartTA;
    int AScfPatLocChangeRL;
    int AScfPatLocChangeAP;
    int AScfPatLocChangeSI;
    int TGpatLocChangeRL;
    int TGpatLocChangeAP;
    int TGpatLocChangeSI;
    int autoshimFOV;
    int fastTGstartTA;
    int fastTGstartRG;
    int fastTGmode;
    int cfhSensitiveAnatomy;
    int aps1Mod;
    int aps1Plane;
    int pureCompatible;
    int maxFOV;
    int assetThresh;
    int scic_a_used;
    int scic_s_used;
    int scic_c_used;
    float aps1ModFOV;
    float aps1ModPStloc;
    float aps1ModPSrloc;
    float opthickPSMod;
    float pureScale;
    float pureCorrectionThreshold;
    float scic_a[7];
    float scic_s[7];
    float scic_c[7];
} APPLICATION_CONFIG_PARAM_TYPE;

typedef struct  application_config_hdr
{
    int error;  
    char clinicalName[24];
    APPLICATION_CONFIG_PARAM_TYPE appConfig;
} APPLICATION_CONFIG_HDR;

/* Coil information structure. Used to communicate information about
   a coil configuration from CIM to PSD */
/* NOTE: Any changes in the COIL_INFO and TX_COIL_INFO will HAVE to 
 * reflect in epic.h. Please change the @reqexport section AS WELL AS 
 * @ipgexport section accordingly */

typedef struct {
    s8 coilName[GE_COIL_NAME_LENGTH_PADDED]; /* GE coil name */
    s32 txIndexPri;        /* Index into txCoilInfo indicating which transmit
                              coil should be used with this receive coil on
                              the primary (master) exciter. */
    s32 txIndexSec;        /* Index into txCoilInfo indicating which transmit
                              coil should be used with this receive coil on
                              the seconday (slave) exciter */
    n32 rxCoilType;        /* Type of receive coil (RX_COIL_BODY or
                              RX_COIL_LOCAL) */
    n32 hubIndex;          /* RF hub index for this coil configuration */
    n32 rxNucleus;         /* Nucleus receive coil designed for */
    n32 aps1Mod;           /* Set if modifications to TG acquisition are desired */
    n32 aps1ModPlane;      /* Scan plane used for TG if aps1Mod is set */
    n32 coilSepDir;        /* Direction of coil separation (for ASSET) */
    n32 assetCalThreshold; /* Calibration threshold for ASSET */
    f32 aps1ModFov;        /* FOV        used for TG if aps1Mod is set */
    f32 aps1ModSlThick;    /* opthickPs  used for TG if aps1Mod is set */
    f32 aps1ModPsTloc;     /* Tloc       used for TG if aps1Mod is set */
    f32 aps1ModPsRloc;     /* Rloc       used for TG if aps1Mod is set */
    f32 autoshimFov;       /* Autoshim FOV */
    f32 assetCalMaxFov;    /* Maximum FOV for ASSET calibration */
    f32 maxB1Rms;          /* B1 RMS value of the total train of RF pulses
                              in the scan sequence that the coil can tolerate */
} COIL_INFO;

/* Trasmit coil information structure. Used to communicate information a
   transmit coil from CIM to PSD */
/* NOTE: Any changes in the COIL_INFO and TX_COIL_INFO will HAVE to
 * reflect in epic.h. Please change the @reqexport section AS WELL AS
 * @ipgexport section accordingly */
typedef struct {
    s32 coilAtten;         /* Extra attenuation set for the transmit coil */
    n32 txCoilType;        /* Type of transmit coil. (TX_COIL_BODY or
                              TX_COIL_LOCAL) */
    n32 txPosition;        /* Transmit location. (TX_POS_BODY, TX_POS_HEAD,
                              TX_POS_EXTREMITY) */
    n32 txNucleus;         /* Nucleus coil designed for */
    n32 txAmp;             /* Amplifier used with this transmit coil
                              (TX_AMP_NB, TX_AMP_BB) */
    f32 maxB1Peak;         /* Maximum peak B1 produced by the transmit coil
                              with any RF pulse */
    f32 maxB1Squared;      /* Maximum integral of square of RF pulse B1
                              amplitude */
    f32 cableLoss;
    f32 coilLoss;
    f32 reflCoeffSquared[REFL_COEFF_SQUARED_LENGTH];
                           /* Power reflected from transmit coil as a
                              function of patient mass */
    f32 reflCoeffMassOffset; /* Offset paramter for the reflCoeffSquared */
    f32 reflCoeffCurveType;  /* Type of refection curve used */
    f32 exposedMass[EXPOSED_MASS_LENGTH];
                           /* Mass of patient exposed to RF transmit energy
                              as a function of total body mass */
    f32 jstd[JSTD_LENGTH]; /* Joules per standard pulse as function of
                              patient mass */
} TX_COIL_INFO;

typedef struct _psd_coil_info_
{
    COIL_INFO imgRcvCoilInfo[MAX_COIL_SETS];
    COIL_INFO volRcvCoilInfo[MAX_COIL_SETS];
    TX_COIL_INFO txCoilInfo[MAX_TX_COIL_SETS];
    TX_COIL_INFO txCoilInfoAdult[MAX_TX_COIL_SETS];
    int numCoils;
    
} PSD_COIL_INFO;

#endif
